@@ -81,7 +81,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, signals => {
     ),
   ];
 
-our $VERSION = '2.1.3';
+our $VERSION = '2.1.5';
 
 my $SANE_NAME_PAGE_HEIGHT = SANE_NAME_PAGE_HEIGHT;
 my $SANE_NAME_PAGE_WIDTH  = SANE_NAME_PAGE_WIDTH;
@@ -216,7 +216,7 @@ sub scan_options {
     delete $self->{option_widgets};
 
     # Ghost the scan button whilst options being updated
-    if ( defined $self->{sbutton} ) { $self->{sbutton}->set_sensitive(FALSE) }
+    $self->set_response_sensitive( 'ok', FALSE );
 
     my ( $pbar, $cache_key );
     my $hboxd = $self->{hboxd};
@@ -342,7 +342,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
         # Notebook page for group
         if ( $opt->{type} == SANE_TYPE_GROUP or not defined $vbox ) {
             $vbox = Gtk3::VBox->new;
-            $vbox->set_border_width( $self->get('border-width') );
+            $vbox->set_border_width( $self->style_get('content-area-border') );
             my $text =
                 $opt->{type} == SANE_TYPE_GROUP
               ? $d_sane->get( $opt->{title} )
@@ -494,8 +494,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
     $self->_update_option_visibility( $options,
         $self->get('visible-scan-options'), $hboxp );
 
-    $self->{sbutton}->set_sensitive(TRUE);
-    $self->{sbutton}->grab_focus;
+    $self->set_response_sensitive( 'ok', TRUE );
     return;
 }
 
