@@ -41,7 +41,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '2.1.4';
+our $VERSION = '2.1.5';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -133,7 +133,7 @@ sub scan_options {
     delete $self->{option_widgets};
 
     # Ghost the scan button whilst options being updated
-    if ( defined $self->{sbutton} ) { $self->{sbutton}->set_sensitive(FALSE) }
+    $self->set_response_sensitive( 'ok', FALSE );
 
     my $signal;
     Gscan2pdf::Frontend::Image_Sane->open_device(
@@ -205,7 +205,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
         # Notebook page for group
         if ( $opt->{type} == SANE_TYPE_GROUP or not defined $vbox ) {
             $vbox = Gtk3::VBox->new;
-            $vbox->set_border_width( $self->get('border-width') );
+            $vbox->set_border_width( $self->style_get('content-area-border') );
             my $text =
                 $opt->{type} == SANE_TYPE_GROUP
               ? $d_sane->get( $opt->{title} )
@@ -358,8 +358,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
         $self->{notebook}->get_nth_page($_)->show_all;
     }
 
-    $self->{sbutton}->set_sensitive(TRUE);
-    $self->{sbutton}->grab_focus;
+    $self->set_response_sensitive( 'ok', TRUE );
     return;
 }
 
